@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2016 ECMWF.
+ * Copyright 2005-2017 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -501,8 +501,11 @@ static int unpack_double(grib_accessor* a, double* val, size_t *len)
         if (i == numberOfGroupsOfDataValues-1) nvals_per_group = trueLengthOfLastGroup;
         Assert (n_vals >= vcount+nvals_per_group);
 
+        /*grib_decode_long_array(buf_vals, &vals_p, nbits_per_group_val, nvals_per_group,
+                               &sec_val[vcount]); */
         for(j=0; j < nvals_per_group;j++){
-            sec_val[vcount+j] = group_ref_val + grib_decode_unsigned_long(buf_vals,  &vals_p, nbits_per_group_val);
+            sec_val[vcount+j] = group_ref_val + grib_decode_unsigned_long(buf_vals, &vals_p, nbits_per_group_val);
+            /* sec_val[vcount+j] += group_ref_val; */
         }
 
         vcount += nvals_per_group;
